# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .bulk_op_type import BulkOpType
import pydantic
from .bulk_op_status import BulkOpStatus
from .providers import Providers
import datetime as dt
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BulkOp(UniversalBaseModel):
    type: BulkOpType = pydantic.Field()
    """
    ℹ️ This enum is non-exhaustive.
    """

    status: BulkOpStatus = pydantic.Field()
    """
    ℹ️ This enum is non-exhaustive.
    """

    provider: Providers
    pending: int
    processed: int
    started_at: dt.datetime
    ended_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
